# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`ca_cert`](#ca_cert): This module manages the shared system-wide truststore.

### Defined types

* [`ca_cert::ca`](#ca_cert--ca): Manage a CA Certificate in the the shared system-wide truststore.

## Classes

### <a name="ca_cert"></a>`ca_cert`

This module manages the shared system-wide truststore.

#### Examples

##### Basic usage

```puppet
class { 'ca_cert': }
```

##### Purge unmanaged user CAs

```puppet
class { 'ca_cert':
  purge_unmanaged_CAs => true,
}
```

##### Custom certificates handling

```puppet
class { 'ca_cert':
  update_cmd        => '/usr/bin/c_rehash',
  trusted_cert_dir  => '/var/ssl/certs,
  cert_dir_group    => 'system',
  cert_dir_mode     => '0755',
  ca_file_group     => 'system',
  ca_file_mode      => '0644',
  ca_file_extension => 'pem',
}
```

#### Parameters

The following parameters are available in the `ca_cert` class:

* [`update_cmd`](#-ca_cert--update_cmd)
* [`trusted_cert_dir`](#-ca_cert--trusted_cert_dir)
* [`distrusted_cert_dir`](#-ca_cert--distrusted_cert_dir)
* [`ca_certificates_conf`](#-ca_cert--ca_certificates_conf)
* [`install_package`](#-ca_cert--install_package)
* [`package_ensure`](#-ca_cert--package_ensure)
* [`package_name`](#-ca_cert--package_name)
* [`cert_dir_group`](#-ca_cert--cert_dir_group)
* [`cert_dir_mode`](#-ca_cert--cert_dir_mode)
* [`ca_file_group`](#-ca_cert--ca_file_group)
* [`ca_file_mode`](#-ca_cert--ca_file_mode)
* [`ca_file_extension`](#-ca_cert--ca_file_extension)
* [`always_update_certs`](#-ca_cert--always_update_certs)
* [`purge_unmanaged_CAs`](#-ca_cert--purge_unmanaged_CAs)
* [`ca_certs`](#-ca_cert--ca_certs)

##### <a name="-ca_cert--update_cmd"></a>`update_cmd`

Data type: `String[1]`

Command to be used to update CA certificates.
Default provided by Hiera for supported Operating Systems.

##### <a name="-ca_cert--trusted_cert_dir"></a>`trusted_cert_dir`

Data type: `Stdlib::Absolutepath`

Absolute directory path to the folder containing trusted certificates.
Default provided by Hiera for supported Operating Systems.

##### <a name="-ca_cert--distrusted_cert_dir"></a>`distrusted_cert_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Absolute directory path to the folder containing distrusted certificates.
Default provided by Hiera for supported Operating Systems.

Default value: `undef`

##### <a name="-ca_cert--ca_certificates_conf"></a>`ca_certificates_conf`

Data type: `Optional[Stdlib::Absolutepath]`

Some distros use a configuration file to mark distrusted certificates.
Default provided by Hiera for supported Operating Systems.

Default value: `undef`

##### <a name="-ca_cert--install_package"></a>`install_package`

Data type: `Boolean`

Whether or not this module should install the ca_certificates package.
The package contains the system default (typically Mozilla) CA
certificates, as well as the tools required for managing other installed
CA certificates.

Default value: `true`

##### <a name="-ca_cert--package_ensure"></a>`package_ensure`

Data type: `Stdlib::Ensure::Package`

The ensure parameter to pass to the package resource.

Default value: `'installed'`

##### <a name="-ca_cert--package_name"></a>`package_name`

Data type: `String[1]`

The name of the package(s) to be installed.

Default value: `'ca-certificates'`

##### <a name="-ca_cert--cert_dir_group"></a>`cert_dir_group`

Data type: `String[1]`

The installed trusted certificate's POSIX group permissions. This uses
the same syntax as Puppet's native file resource's "group" parameter.

Default value: `'root'`

##### <a name="-ca_cert--cert_dir_mode"></a>`cert_dir_mode`

Data type: `Stdlib::Filemode`

The installed  trusted certificate's POSIX filesystem permissions. This uses
the same syntax as Puppet's native file resource's "mode" parameter.

Default value: `'0755'`

##### <a name="-ca_cert--ca_file_group"></a>`ca_file_group`

Data type: `String[1]`

The installed CA certificate's POSIX group permissions. This uses
the same syntax as Puppet's native file resource's "group" parameter.

Default value: `'root'`

##### <a name="-ca_cert--ca_file_mode"></a>`ca_file_mode`

Data type: `Stdlib::Filemode`

The installed CA certificate's POSIX filesystem permissions. This uses
the same syntax as Puppet's native file resource's "mode" parameter.

Default value: `'0644'`

##### <a name="-ca_cert--ca_file_extension"></a>`ca_file_extension`

Data type: `String[1]`

File extenstion for the certificate.

Default value: `'crt'`

##### <a name="-ca_cert--always_update_certs"></a>`always_update_certs`

Data type: `Boolean`

Run the appropriate update CA certificates command for your operating
system on every Puppet run whether it is needed or not.

Default value: `false`

##### <a name="-ca_cert--purge_unmanaged_CAs"></a>`purge_unmanaged_CAs`

Data type: `Boolean`

When set to true (default: false), user installed CA
certificates (in the appropriate directories) not managed by this
module will be purged.

Default value: `false`

##### <a name="-ca_cert--ca_certs"></a>`ca_certs`

Data type: `Hash`

A hash of CA certificates that should be installed as part of the class
declaration.

Default value: `{}`

## Defined types

### <a name="ca_cert--ca"></a>`ca_cert::ca`

Manage a CA Certificate in the the shared system-wide truststore.

#### Examples

##### 

```puppet
ca_cert::ca { 'globalsign_org_intermediate':
  source => 'http://secure.globalsign.com/cacert/gsorganizationvalsha2g2r1.crt',
}
```

#### Parameters

The following parameters are available in the `ca_cert::ca` defined type:

* [`ensure`](#-ca_cert--ca--ensure)
* [`allow_insecure_source`](#-ca_cert--ca--allow_insecure_source)
* [`source`](#-ca_cert--ca--source)
* [`content`](#-ca_cert--ca--content)
* [`checksum`](#-ca_cert--ca--checksum)
* [`checksum_type`](#-ca_cert--ca--checksum_type)
* [`proxy_server`](#-ca_cert--ca--proxy_server)
* [`proxy_type`](#-ca_cert--ca--proxy_type)

##### <a name="-ca_cert--ca--ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'trusted', 'distrusted']`

Whether or not the CA certificate should be on a system or not.
- `present`/`absent` is used to manage local/none default CAs.
- `trusted`/`distrusted` is used to manage system CAs.

Default value: `'present'`

##### <a name="-ca_cert--ca--allow_insecure_source"></a>`allow_insecure_source`

Data type: `Boolean`

Whether to allow insecure download or not.

Default value: `false`

##### <a name="-ca_cert--ca--source"></a>`source`

Data type: `Optional[String[1]]`

A source certificate, which will be copied into place on the local system.
This attribute is mutually exclusive with `content`
Uri support, see puppet-archive.

Default value: `undef`

##### <a name="-ca_cert--ca--content"></a>`content`

Data type: `Optional[String[1]]`

PEM formatted certificate content
This attribute is mutually exclusive with `source`

Default value: `undef`

##### <a name="-ca_cert--ca--checksum"></a>`checksum`

Data type: `Optional[String[1]]`

The checksum of the file.

Default value: `undef`

##### <a name="-ca_cert--ca--checksum_type"></a>`checksum_type`

Data type: `Optional[String[1]]`

The type of file checksum.

Default value: `undef`

##### <a name="-ca_cert--ca--proxy_server"></a>`proxy_server`

Data type: `Optional[String[1]]`

Proxy address to use when accessing source

Default value: `undef`

##### <a name="-ca_cert--ca--proxy_type"></a>`proxy_type`

Data type: `Optional[String[1]]`

Proxy type ( See `archive::proxy_type )

Default value: `undef`

